# $Id: 07_shellcmd.t,v 1.4 2008/07/16 16:55:04 pythontech Exp $
use strict;
use Test::More tests => 8;

use lib 't/lib';
use DbUtil;

use PythonTech::Triples::DBHash;
use PythonTech::Triples::ShellCmd;
use DB_File;

my $dbname = 't/new03.3db';

# Create test data
dbwrite($dbname, '
v1 = a
v2 = b
v3 = c
v4 = ="d"
v5 = e
ia = 1
ib = 2
ic = 3
i="d" = 4
ie = 5
l = 5
t1,2,3 = 1
t1,2,4 = 1
t1,5,3 = 1
o1,2 = 3+4
o1,5 = 3
s2,3 = 1
s2,4 = 1
s5,3 = 1
');

my $tr = new PythonTech::Triples::DBHash(filename => $dbname,
					 access => 'r');
my $sh = new PythonTech::Triples::ShellCmd(triples => $tr);

is(&run('info'),"class: PythonTech::Triples::DBHash\nfeatures: \nlast_id: 5\n", 'info');
$tr->configure(index_s2p => 1);
is(&run('info'),"class: PythonTech::Triples::DBHash\nfeatures: index_s2p\nlast_id: 5\n", 'info');
is(&run('show','a'),"b\tc\nb\t=\"d\"\ne\tc\n", 'show');
is(&run('query','?','?','c'), "a b\na e\n", 'query');
is(&run('ntriples'), "<a> <b> <c> .\n<a> <b> \"\\\"d\\\"\" .\n<a> <e> <c> .\n", 'ntriples');
is(&run('add','a','b','f'), "", 'add');
is(&run('remove','a','b','c'), "", 'remove');

$tr = undef;

my $expected = join('', map {"$_\n"} sort
		    'f = p',
		    'v1 = a', 'ia = 1',
		    'v2 = b', 'ib = 2',
		    'v3 = c', 'ic = 3',
		    'v4 = =%22d%22', 'i=%22d%22 = 4',
		    'v5 = e', 'ie = 5',
		    'v6 = f', 'if = 6',
		    'l = 6',
		    't1,2,4 = 1',
		    't1,5,3 = 1',
		    't1,2,6 = 1',
		    'o1,2 = 4+6',
		    'o1,5 = 3',
		    's2,4 = 1',
		    's5,3 = 1',
		    's2,6 = 1',
		    'p1 = 2+5');
is(&dbread($dbname), $expected, 'db data after add/remove triples');

unlink($dbname);

sub qt {
    join(";", sort map {join(",",@$_)} @_);
}

sub j {join(",",sort @_)}

sub run {
    my(@args) = @_;
    if (open(RUN,'-|')) {
	# Parent
	local($/);
	my $output = <RUN>;
	close(RUN);
	return $output;
    } else {
	# Child
	$sh->main('3sh',@args);
	exit;
    }
}
